@@ -1,11 +1,11 @@
-from django.http import HttpResponse
-
+"""JSON helper functions"""
 try:
     import simplejson as json
 except ImportError:
     import json
 
-# JSON helper functions
+from django.http import HttpResponse
+
 
 def JSONResponse(data, dump=True):
     try:
